aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/cctest/makefile5
-rw-r--r--src/cctest/test-cstdio-global.cc1
-rw-r--r--src/cctest/test-stdio_h-std.cc6
3 files changed, 7 insertions, 5 deletions
diff --git a/src/cctest/makefile b/src/cctest/makefile
index 4d0453f..d46d7c3 100644
--- a/src/cctest/makefile
+++ b/src/cctest/makefile
@@ -2,7 +2,7 @@
CXX = gcc -W -Wall -pedantic -ansi
-test-namespaces :
+test-namespace :
-$(CXX) -o test-stdio_h-global test-stdio_h-global.cc
-./test-stdio_h-global
-$(CXX) -o test-stdio_h-std test-stdio_h-std.cc
@@ -11,3 +11,6 @@ test-namespaces :
-./test-cstdio-global
-$(CXX) -o test-cstdio-std test-cstdio-std.cc
-./test-cstdio-std
+clean-namespace :
+ -rm -f test-stdio_h-global test-stdio_h-std \
+ test-cstdio-global test-cstdio-std
diff --git a/src/cctest/test-cstdio-global.cc b/src/cctest/test-cstdio-global.cc
index b3c10e6..948d32d 100644
--- a/src/cctest/test-cstdio-global.cc
+++ b/src/cctest/test-cstdio-global.cc
@@ -2,7 +2,6 @@
// $Header$
#include <cstdio>
-//using std::printf;
int main()
{
diff --git a/src/cctest/test-stdio_h-std.cc b/src/cctest/test-stdio_h-std.cc
index 32f539b..855c80f 100644
--- a/src/cctest/test-stdio_h-std.cc
+++ b/src/cctest/test-stdio_h-std.cc
@@ -1,11 +1,11 @@
// test-cstdio-std.cc -- test <cstdio> functions in std:: namespace
// $Header$
-#include <cstdio>
+#include <stdio.h>
using std::printf;
int main()
{
-printf("==> <cstdio> fns in the std:: namespace are ok\n");
+printf("==> <stdio.h> fns in the std:: namespace are ok\n");
return 0;
}
@@ -1,11 +1,11 @@
-// test-cstdio-std.cc -- test <cstdio> functions in std:: namespace
+// test-stdio_h-std.cc -- test <stdio.h> functions in std:: namespace
// $Header$